@@ -1,17 +1,17 @@
 /*
  * Copyright 2011 Red Hat, Inc. and/or its affiliates.
  *
- * Licensed under the Apache License, Version 2.0 (the "License"); you may not
- * use this file except in compliance with the License. You may obtain a copy of
- * the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations under
- * the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package org.drools.workbench.screens.guided.dtable.client.widget.table;
 
@@ -23,6 +23,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
@@ -31,10 +32,7 @@ import javax.inject.Inject;
 import com.google.gwt.event.shared.EventBus;
 import com.google.gwt.event.shared.SimpleEventBus;
 import com.google.gwt.user.client.Command;
-import org.drools.workbench.models.datamodel.oracle.DateConverter;
-import org.drools.workbench.models.datamodel.oracle.DropDownData;
-import org.drools.workbench.models.datamodel.rule.FactPattern;
-import org.drools.workbench.models.datamodel.rule.IPattern;
+import org.drools.verifier.api.reporting.Issue;
 import org.drools.workbench.models.datamodel.workitems.PortableWorkDefinition;
 import org.drools.workbench.models.guided.dtable.shared.auditlog.DeleteColumnAuditLogEntry;
 import org.drools.workbench.models.guided.dtable.shared.auditlog.DeleteRowAuditLogEntry;
@@ -62,7 +60,6 @@ import org.drools.workbench.screens.guided.dtable.client.editor.clipboard.impl.D
 import org.drools.workbench.screens.guided.dtable.client.type.GuidedDTableResourceType;
 import org.drools.workbench.screens.guided.dtable.client.widget.analysis.DecisionTableAnalyzerProvider;
 import org.drools.workbench.screens.guided.dtable.client.widget.analysis.controller.AnalyzerController;
-import org.drools.workbench.screens.guided.dtable.client.widget.analysis.panel.IssueSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.auditlog.AuditLog;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.BooleanUiColumn;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableColumnSelectedEvent;
@@ -71,6 +68,7 @@ import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshActionsPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshAttributesPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshConditionsPanelEvent;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshMenusEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshMetaDataPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.lockmanager.GuidedDecisionTableLockManager;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.GuidedDecisionTableUiCell;
@@ -79,6 +77,7 @@ import org.drools.workbench.screens.guided.dtable.client.widget.table.model.conv
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.BaseColumnConverter;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.GridWidgetColumnFactory;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoException;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.Synchronizer;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.themes.GuidedDecisionTableRenderer;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.utilities.CellUtilities;
@@ -88,15 +87,17 @@ import org.drools.workbench.screens.guided.dtable.client.widget.table.utilities.
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableLinkManager;
 import org.drools.workbench.screens.guided.rule.client.util.GWTDateConverter;
-import org.drools.workbench.services.verifier.api.client.reporting.Issue;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ioc.client.container.SyncBeanDef;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.jboss.errai.security.shared.api.identity.User;
+import org.kie.soup.project.datamodel.oracle.DateConverter;
+import org.kie.soup.project.datamodel.oracle.DropDownData;
 import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
 import org.kie.workbench.common.services.shared.rulename.RuleNamesService;
+import org.kie.workbench.common.services.verifier.reporting.client.panel.IssueSelectedEvent;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracleFactory;
 import org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants;
@@ -137,6 +138,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
     private final Event<RefreshMetaDataPanelEvent> refreshMetaDataPanelEvent;
     private final Event<RefreshConditionsPanelEvent> refreshConditionsPanelEvent;
     private final Event<RefreshActionsPanelEvent> refreshActionsPanelEvent;
+    private final Event<RefreshMenusEvent> refreshMenusEvent;
     private final Event<NotificationEvent> notificationEvent;
     private final GridWidgetCellFactory gridWidgetCellFactory;
     private final GridWidgetColumnFactory gridWidgetColumnFactory;
@@ -190,6 +192,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
                                         final Event<RefreshMetaDataPanelEvent> refreshMetaDataPanelEvent,
                                         final Event<RefreshConditionsPanelEvent> refreshConditionsPanelEvent,
                                         final Event<RefreshActionsPanelEvent> refreshActionsPanelEvent,
+                                        final Event<RefreshMenusEvent> refreshMenusEvent,
                                         final Event<NotificationEvent> notificationEvent,
                                         final GridWidgetCellFactory gridWidgetCellFactory,
                                         final GridWidgetColumnFactory gridWidgetColumnFactory,
@@ -215,6 +218,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         this.refreshMetaDataPanelEvent = refreshMetaDataPanelEvent;
         this.refreshConditionsPanelEvent = refreshConditionsPanelEvent;
         this.refreshActionsPanelEvent = refreshActionsPanelEvent;
+        this.refreshMenusEvent = refreshMenusEvent;
         this.notificationEvent = notificationEvent;
         this.gridWidgetCellFactory = gridWidgetCellFactory;
         this.gridWidgetColumnFactory = gridWidgetColumnFactory;
@@ -407,6 +411,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
             @Override
             public Range deleteCell(int rowIndex,
                                     int columnIndex) {
+
                 Range cellRange = super.deleteCell(rowIndex,
                                                    columnIndex);
                 decisionTableSelectionsChangedEvent.fire(new DecisionTableSelectionsChangedEvent(GuidedDecisionTablePresenter.this));
@@ -513,12 +518,10 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         view.registerNodeMouseDoubleClickHandler((event) -> {
             if (view.isNodeMouseEventOverCaption(event)) {
                 if (isGridPinned()) {
-                    exitPinnedMode(() -> {
-                        /*Nothing*/});
+                    exitPinnedMode(() -> {/*Nothing*/});
                 } else {
                     enterPinnedMode(view,
-                                    () -> {
-                                        /*Nothing*/});
+                                    () -> {/*Nothing*/});
                 }
             }
         });
@@ -625,10 +628,22 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
             } else {
                 access.setLock(NOBODY);
             }
-            parent.onLockStatusUpdated(this);
+            refreshColumnsPage();
+            refreshMenus();
         }
     }
 
+    void refreshColumnsPage() {
+        refreshAttributesPanelEvent.fire(new RefreshAttributesPanelEvent(this, model.getAttributeCols()));
+        refreshMetaDataPanelEvent.fire(new RefreshMetaDataPanelEvent(this, model.getMetadataCols()));
+        refreshConditionsPanelEvent.fire(new RefreshConditionsPanelEvent(this, model.getConditions()));
+        refreshActionsPanelEvent.fire(new RefreshActionsPanelEvent(this, model.getActionCols()));
+    }
+
+    void refreshMenus() {
+        refreshMenusEvent.fire(new RefreshMenusEvent());
+    }
+
     void onIssueSelectedEvent(final @Observes IssueSelectedEvent event) {
         if (event == null) {
             return;
@@ -722,7 +737,13 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
 
     @Override
     public boolean hasColumnDefinitions() {
-        return model.getAttributeCols().size() > 0 || model.getConditionsCount() > 0 || model.getActionCols().size() > 0;
+
+        final boolean hasAttributeCols = model.getAttributeCols().size() > 0;
+        final boolean hasMetadataCols = model.getMetadataCols().size() > 0;
+        final boolean hasConditionCols = model.getConditionsCount() > 0;
+        final boolean hasActionCols = model.getActionCols().size() > 0;
+
+        return hasAttributeCols || hasConditionCols || hasActionCols || hasMetadataCols;
     }
 
     @Override
@@ -760,37 +781,6 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         return rm.getLHSBoundFacts();
     }
 
-    @Override
-    public boolean canConditionBeDeleted(final ConditionCol52 col) {
-        Pattern52 pattern = model.getPattern(col);
-        if (pattern.getChildColumns().size() > 1) {
-            return true;
-        }
-        if (isBindingUsed(pattern.getBoundName())) {
-            return false;
-        }
-        return true;
-    }
-
-    @Override
-    public boolean canConditionBeDeleted(final BRLConditionColumn col) {
-        for (IPattern p : col.getDefinition()) {
-            if (p instanceof FactPattern) {
-                FactPattern fp = (FactPattern) p;
-                if (fp.isBound()) {
-                    if (isBindingUsed(fp.getBoundName())) {
-                        return false;
-                    }
-                }
-            }
-        }
-        return true;
-    }
-
-    private boolean isBindingUsed(final String binding) {
-        return rm.isBoundFactUsed(binding);
-    }
-
     @Override
     public Map<String, String> getValueListLookups(final BaseColumn column) {
         final String[] dropDownItems = columnUtilities.getValueList(column);
@@ -900,7 +890,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
     }
 
     private void doAppendColumn(final BaseColumn column,
-                                final VetoableCommand append,
+                                final VetoableColumnCommand append,
                                 final Command callback) {
         if (isReadOnly()) {
             return;
@@ -914,8 +904,8 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
             model.getAuditLog().add(new InsertColumnAuditLogEntry(identity.getIdentifier(),
                                                                   column));
             callback.execute();
-        } catch (ModelSynchronizer.MoveColumnVetoException e) {
-            //Swallow. The VetoException signals that the column could not be appended.
+        } catch (VetoException e) {
+            getModellerPresenter().getView().showGenericVetoMessage();
         }
     }
 
@@ -932,8 +922,8 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
             //Log insertion of row
             model.getAuditLog().add(new InsertRowAuditLogEntry(identity.getIdentifier(),
                                                                model.getData().size() - 1));
-        } catch (ModelSynchronizer.MoveColumnVetoException e) {
-            //Swallow
+        } catch (VetoException e) {
+            getModellerPresenter().getView().showGenericVetoMessage();
         }
     }
 
@@ -945,55 +935,51 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
     }
 
     @Override
-    public void deleteColumn(final AttributeCol52 column) {
+    public void deleteColumn(final AttributeCol52 column) throws VetoException {
         doDeleteColumn(column,
                        () -> refreshAttributesPanelEvent.fire(new RefreshAttributesPanelEvent(this,
                                                                                               model.getAttributeCols())));
     }
 
     @Override
-    public void deleteColumn(final MetadataCol52 column) {
+    public void deleteColumn(final MetadataCol52 column) throws VetoException {
         doDeleteColumn(column,
                        () -> refreshMetaDataPanelEvent.fire(new RefreshMetaDataPanelEvent(this,
                                                                                           model.getMetadataCols())));
     }
 
     @Override
-    public void deleteColumn(final ConditionCol52 column) {
+    public void deleteColumn(final ConditionCol52 column) throws VetoException {
         doDeleteColumn(column,
                        () -> refreshConditionsPanelEvent.fire(new RefreshConditionsPanelEvent(this,
                                                                                               model.getConditions())));
     }
 
     @Override
-    public void deleteColumn(final ActionCol52 column) {
+    public void deleteColumn(final ActionCol52 column) throws VetoException {
         doDeleteColumn(column,
                        () -> refreshActionsPanelEvent.fire(new RefreshActionsPanelEvent(this,
                                                                                         model.getActionCols())));
     }
 
     private void doDeleteColumn(final BaseColumn column,
-                                final Command callback) {
+                                final Command callback) throws VetoException {
         if (isReadOnly()) {
             return;
         }
-        try {
-            synchronizer.deleteColumn(column);
+        synchronizer.deleteColumn(column);
 
-            refreshView();
+        refreshView();
 
-            //Log deletion of column
-            model.getAuditLog().add(new DeleteColumnAuditLogEntry(identity.getIdentifier(),
-                                                                  column));
-            callback.execute();
-        } catch (ModelSynchronizer.MoveColumnVetoException e) {
-            //Swallow. The VetoException signals that the column could not be deleted.
-        }
+        //Log deletion of column
+        model.getAuditLog().add(new DeleteColumnAuditLogEntry(identity.getIdentifier(),
+                                                              column));
+        callback.execute();
     }
 
     @Override
     public void updateColumn(final AttributeCol52 originalColumn,
-                             final AttributeCol52 editedColumn) {
+                             final AttributeCol52 editedColumn) throws VetoException {
         doUpdateColumn(originalColumn,
                        editedColumn,
                        () -> synchronizer.updateColumn(originalColumn,
@@ -1004,7 +990,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
 
     @Override
     public void updateColumn(final MetadataCol52 originalColumn,
-                             final MetadataCol52 editedColumn) {
+                             final MetadataCol52 editedColumn) throws VetoException {
         doUpdateColumn(originalColumn,
                        editedColumn,
                        () -> synchronizer.updateColumn(originalColumn,
@@ -1017,7 +1003,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
     public void updateColumn(final Pattern52 originalPattern,
                              final ConditionCol52 originalColumn,
                              final Pattern52 editedPattern,
-                             final ConditionCol52 editedColumn) {
+                             final ConditionCol52 editedColumn) throws VetoException {
         doUpdateColumn(originalColumn,
                        editedColumn,
                        () -> synchronizer.updateColumn(originalPattern,
@@ -1030,7 +1016,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
 
     @Override
     public void updateColumn(final ConditionCol52 originalColumn,
-                             final ConditionCol52 editedColumn) {
+                             final ConditionCol52 editedColumn) throws VetoException {
         doUpdateColumn(originalColumn,
                        editedColumn,
                        () -> synchronizer.updateColumn(originalColumn,
@@ -1041,7 +1027,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
 
     @Override
     public void updateColumn(final ActionCol52 originalColumn,
-                             final ActionCol52 editedColumn) {
+                             final ActionCol52 editedColumn) throws VetoException {
         doUpdateColumn(originalColumn,
                        editedColumn,
                        () -> synchronizer.updateColumn(originalColumn,
@@ -1052,27 +1038,23 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
 
     private void doUpdateColumn(final BaseColumn originalColumn,
                                 final BaseColumn editedColumn,
-                                final VetoableUpdateCommand update,
-                                final Command callback) {
+                                final VetoableUpdateColumnCommand update,
+                                final Command callback) throws VetoException {
         if (isReadOnly()) {
             return;
         }
-        try {
-            final List<BaseColumnFieldDiff> diffs = update.execute();
+        final List<BaseColumnFieldDiff> diffs = update.execute();
 
-            parent.updateLinks();
+        parent.updateLinks();
 
-            //Log change to column definition
-            if (!(diffs == null || diffs.isEmpty())) {
-                view.getLayer().draw();
-                model.getAuditLog().add(new UpdateColumnAuditLogEntry(identity.getIdentifier(),
-                                                                      originalColumn,
-                                                                      editedColumn,
-                                                                      diffs));
-                callback.execute();
-            }
-        } catch (ModelSynchronizer.MoveColumnVetoException e) {
-            //Swallow. The VetoException signals that the column could not be updated.
+        //Log change to column definition
+        if (!(diffs == null || diffs.isEmpty())) {
+            view.getLayer().draw();
+            model.getAuditLog().add(new UpdateColumnAuditLogEntry(identity.getIdentifier(),
+                                                                  originalColumn,
+                                                                  editedColumn,
+                                                                  diffs));
+            callback.execute();
         }
     }
 
@@ -1100,17 +1082,17 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
 
             //BaseGridData is sparsely populated; only add values if needed.
             if (modelCell.hasValue()) {
-                uiModel.setCellInternal(rowIndex,
-                                        iModelColumn,
-                                        gridWidgetCellFactory.convertCell(modelCell,
-                                                                          modelColumn,
-                                                                          cellUtilities,
-                                                                          columnUtilities));
+                uiModel.setCellValueInternal(rowIndex,
+                                             iModelColumn,
+                                             gridWidgetCellFactory.convertCell(modelCell,
+                                                                               modelColumn,
+                                                                               cellUtilities,
+                                                                               columnUtilities));
 
                 //Set-up SelectionManager for Row Number column, to select entire row.
                 if (modelColumn instanceof RowNumberCol52) {
                     uiModel.getCell(rowIndex,
-                                    iModelColumn).setSelectionManager(RowSelectionStrategy.INSTANCE);
+                                    iModelColumn).setSelectionStrategy(RowSelectionStrategy.INSTANCE);
                 }
             }
         }
@@ -1198,12 +1180,12 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
             final DTCellValue52 modelCell = cd.getValue();
             final BaseColumn modelColumn = model.getExpandedColumns().get(targetColumnIndex);
             if (modelCell.hasValue()) {
-                uiModel.setCell(targetRowIndex,
-                                targetColumnIndex,
-                                gridWidgetCellFactory.convertCell(modelCell,
-                                                                  modelColumn,
-                                                                  cellUtilities,
-                                                                  columnUtilities));
+                uiModel.setCellValue(targetRowIndex,
+                                     targetColumnIndex,
+                                     gridWidgetCellFactory.convertCell(modelCell,
+                                                                       modelColumn,
+                                                                       cellUtilities,
+                                                                       columnUtilities));
             } else {
                 uiModel.deleteCell(targetRowIndex,
                                    targetColumnIndex);
@@ -1241,9 +1223,9 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
                 continue;
             }
             if (uiColumn instanceof BooleanUiColumn) {
-                uiModel.setCell(rowIndex,
-                                columnIndex,
-                                new GuidedDecisionTableUiCell<>(false));
+                uiModel.setCellValue(rowIndex,
+                                     columnIndex,
+                                     new GuidedDecisionTableUiCell<>(false));
             } else {
                 uiModel.deleteCell(rowIndex,
                                    columnIndex);
@@ -1268,13 +1250,29 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         }
         for (BaseColumn columnToDelete : columnsToDelete) {
             if (columnToDelete instanceof AttributeCol52) {
-                deleteColumn((AttributeCol52) columnToDelete);
+                try {
+                    deleteColumn((AttributeCol52) columnToDelete);
+                } catch (VetoException veto) {
+                    getModellerPresenter().getView().showGenericVetoMessage();
+                }
             } else if (columnToDelete instanceof MetadataCol52) {
-                deleteColumn((MetadataCol52) columnToDelete);
+                try {
+                    deleteColumn((MetadataCol52) columnToDelete);
+                } catch (VetoException veto) {
+                    getModellerPresenter().getView().showGenericVetoMessage();
+                }
             } else if (columnToDelete instanceof ConditionCol52) {
-                deleteColumn((ConditionCol52) columnToDelete);
+                try {
+                    deleteColumn((ConditionCol52) columnToDelete);
+                } catch (VetoException veto) {
+                    getModellerPresenter().getView().showUnableToDeleteColumnMessage((ConditionCol52) columnsToDelete);
+                }
             } else if (columnToDelete instanceof ActionCol52) {
-                deleteColumn((ActionCol52) columnToDelete);
+                try {
+                    deleteColumn((ActionCol52) columnToDelete);
+                } catch (VetoException veto) {
+                    getModellerPresenter().getView().showUnableToDeleteColumnMessage((ActionCol52) columnsToDelete);
+                }
             }
         }
     }
@@ -1319,8 +1317,8 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
             //Log deletion of column
             model.getAuditLog().add(new DeleteRowAuditLogEntry(identity.getIdentifier(),
                                                                rowIndex));
-        } catch (ModelSynchronizer.MoveColumnVetoException e) {
-            //Swallow
+        } catch (VetoException e) {
+            getModellerPresenter().getView().showGenericVetoMessage();
         }
     }
 
@@ -1378,8 +1376,8 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
             //Log insertion of row
             model.getAuditLog().add(new InsertRowAuditLogEntry(identity.getIdentifier(),
                                                                rowIndex));
-        } catch (ModelSynchronizer.MoveColumnVetoException e) {
-            //Swallow
+        } catch (VetoException e) {
+            getModellerPresenter().getView().showGenericVetoMessage();
         }
     }
 
@@ -1469,14 +1467,14 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         this.concurrentUpdateSessionInfo = concurrentUpdateSessionInfo;
     }
 
-    private interface VetoableCommand {
+    private interface VetoableColumnCommand {
 
-        void execute() throws ModelSynchronizer.MoveColumnVetoException;
+        void execute() throws VetoException;
     }
 
-    private interface VetoableUpdateCommand {
+    private interface VetoableUpdateColumnCommand {
 
-        List<BaseColumnFieldDiff> execute() throws ModelSynchronizer.MoveColumnVetoException;
+        List<BaseColumnFieldDiff> execute() throws VetoException;
     }
 
     public static class Access {
