@@ -33,7 +33,7 @@ import org.drools.workbench.screens.testscenario.model.TestScenarioModelContent;
 import org.drools.workbench.screens.testscenario.model.TestScenarioResult;
 import org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
-import org.guvnor.common.services.shared.test.TestService;
+import org.guvnor.common.services.shared.test.TestRunnerService;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.security.shared.api.identity.User;
@@ -52,7 +52,6 @@ import org.uberfire.ext.widgets.common.client.callbacks.HasBusyIndicatorDefaultE
 import org.uberfire.lifecycle.OnClose;
 import org.uberfire.lifecycle.OnMayClose;
 import org.uberfire.lifecycle.OnStartup;
-import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.workbench.model.menu.Menus;
 
@@ -65,7 +64,7 @@ public class ScenarioEditorPresenter
     private final ScenarioEditorView view;
     private final Caller<ScenarioTestEditorService> service;
     private final AsyncPackageDataModelOracleFactory oracleFactory;
-    private final Caller<TestService> testService;
+    private final Caller<TestRunnerService> testService;
     private final ImportsWidgetPresenter importsWidget;
     private User user;
     private final SettingsPage settingsPage;
@@ -80,7 +79,7 @@ public class ScenarioEditorPresenter
                                    final User user,
                                    final ImportsWidgetPresenter importsWidget,
                                    final Caller<ScenarioTestEditorService> service,
-                                   final Caller<TestService> testService,
+                                   final Caller<TestRunnerService> testService,
                                    final TestScenarioResourceType type,
                                    final AsyncPackageDataModelOracleFactory oracleFactory,
                                    final SettingsPage settingsPage,
@@ -107,11 +106,6 @@ public class ScenarioEditorPresenter
                    type);
     }
 
-    @Override
-    protected Command onValidate() {
-        return null;
-    }
-
     protected void loadContent() {
         view.showLoading();
         service.call(getModelSuccessCallback(),
@@ -263,6 +257,8 @@ public class ScenarioEditorPresenter
                                assetUpdateValidator);
         }
 
+        addDownloadMenuItem(fileMenuBuilder);
+
         fileMenuBuilder
                 .addNewTopLevelMenu(view.getRunScenarioMenuItem())
                 .addNewTopLevelMenu(view.getRunAllScenariosMenuItem())
